library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.numeric_std.all;

--
-- xsocVGAStripes Example Project
-- Doug Hodson, Jun 2003
-- www.RetroMicro.com
--
entity chipIO is
	
	port(
		pin_clkin : in std_logic;       -- main clock input from external clock source
		pin_ce_n  : out std_logic;      -- Flash RAM chip-enable
		
		-- vga port connections
		pin_red     : out std_logic_vector(1 downto 0);
		pin_green   : out std_logic_vector(1 downto 0);
		pin_blue    : out std_logic_vector(1 downto 0);
		pin_hsync_n : out std_logic;
		pin_vsync_n : out std_logic
	);
	
end chipIO;

architecture arch of chipIO is

	constant YES:	std_logic := '1';
	constant NO:	std_logic := '0';
	constant HI:	std_logic := '1';
	constant LO:	std_logic := '0';

	-- vga component
	component vga
		port(
		clk: in std_logic;       -- global clock
		rst: in std_logic;       -- global async reset
		vack: in std_logic;      -- video data DMA acknowledge
		pixels_in: in std_logic_vector(15 downto 0); -- video data in
		vreq: out std_logic;     -- video data DMA request
		vreset: out std_logic;   -- video data reset DMA counter request
		hsync_n: out std_logic;  -- active low horz sync
		vsync_n: out std_logic;  -- active low vert sync
		r: out std_logic_vector(1 downto 0);  -- red
		g: out std_logic_vector(1 downto 0);  -- green
		b: out std_logic_vector(1 downto 0)   -- blue		
		);
	end component;

	-- vga signals
	signal vga_vack      : std_logic;       -- video data DMA acknowledge
	signal vga_pixels_in : std_logic_vector(15 downto 0); -- video data in
	signal vga_vreq      : std_logic;       -- video data DMA request
	signal vga_vreset    : std_logic;       -- video data reset DMA counter request

begin

	pin_ce_n <= '1';		-- disable Flash RAM

	--
	-- when vga need pixel data, provide it!
	--
	process(vga_vreq)
	begin
		if (vga_vreq = YES) then
			vga_pixels_in <= "1111111100000000";
			vga_vack <= YES;
		else
			vga_vack <= NO;         -- reset acknowledge
		end if;
	end process;

	-- vga component
	u1: vga
	port map(
		clk        => pin_clkin,
		rst        => NO,
		vack       => vga_vack,
		pixels_in  => vga_pixels_in,
		vreq       => vga_vreq,
		vreset     => vga_vreset,
		hsync_n    => pin_hsync_n,
		vsync_n    => pin_vsync_n,
		r          => pin_red,
		g          => pin_green,
		b          => pin_blue
		);

end arch;
